diff --git src/password-store.sh src/password-store.sh
index fe306b7..ca9a2a2 100755
--- src/password-store.sh
+++ src/password-store.sh
@@ -205,6 +205,21 @@ case "$command" in
 
 		if [ -d /dev/shm -a -w /dev/shm -a -x /dev/shm ]; then
 			tmp_dir="$(TMPDIR=/dev/shm mktemp -t $template -d)"
+		elif [ "$(uname)" = "Darwin" ]; then
+			cleanup_ramdisk() {
+				umount "$mount_point"
+				diskutil eject $ramdisk_dev
+				rmdir "$mount_point"
+			}
+			ramfs_size_mb=16
+			mount_point=~/.${RANDOM}pass
+			ramfs_size_sectors=$(($ramfs_size_mb*2048))
+			trap cleanup_ramdisk INT TERM EXIT
+			ramdisk_dev="$(hdid -nomount ram://$ramfs_size_sectors)"
+			newfs_hfs -v 'Volatile' -M 700 $ramdisk_dev
+			mkdir -m 700 -p "$mount_point"
+			mount -o noatime -t hfs $ramdisk_dev "$mount_point"
+			tmp_dir="$mount_point"
 		else
 			echo    "Your system does not have /dev/shm, which means that it may"
 			echo    "be difficult to entirely erase the temporary non-encrypted"
